@@ -15,7 +15,7 @@ G_BEGIN_DECLS
 
 #ifdef ORBIT2_INTERNAL_API
 
-void        giop_init              (gboolean threaded,
+void        giop_init              (gboolean thread_safe,
 				    gboolean blank_wire_data);
 void        giop_main_run          (void);
 void        giop_shutdown          (void);
