@@ -29,6 +29,8 @@
 #include "config.h"
 #include "orbit/orbit.h"
 #include "orb-core/orb-core-private.h"
+#include "../orbit-init.h"
+#include "../util/orbit-purify.h"
 
 #define o_return_val_if_fail(expr, val) if(!(expr)) { CORBA_exception_set_system (ev, ex_CORBA_BAD_PARAM, CORBA_COMPLETED_NO); return (val); }
 #define o_return_if_fail(expr)          if(!(expr)) { CORBA_exception_set_system (ev, ex_CORBA_BAD_PARAM, CORBA_COMPLETED_NO); return; }
@@ -183,7 +185,8 @@ DynamicAny_DynAny_release_fn (ORBit_RootObject robj)
 	dynany->children = NULL;
 
 	g_free (dynany);
-	g_free (robj);
+
+	p_free (robj, struct DynamicAny_DynAny_type);
 }
 
 static CORBA_TypeCode
@@ -398,12 +401,18 @@ dynany_any_new_default (const CORBA_TypeCode tc)
 	gpointer value;
 	gpointer p;
 
-	p = value = ORBit_alloc_tcval (tc, 1);
+	p = value = ORBit_alloc_by_tc (tc);
 	dynany_init_default (&p, tc);
 
 	return value;
 }
 
+gpointer
+ORBit_dynany_new_default (const CORBA_TypeCode tc)
+{
+	return dynany_any_new_default (tc);
+}
+
 static gboolean
 dynany_sequence_realloc_to (CORBA_sequence_CORBA_octet *s,
 			    CORBA_TypeCode        sequence_tc,
@@ -638,6 +647,13 @@ dynany_create (const CORBA_TypeCode type,
 	return CORBA_OBJECT_NIL;
 }
 
+DynamicAny_DynAnyFactory
+ORBit_DynAnyFactory_new (CORBA_ORB orb, CORBA_Environment *ev)
+{
+	/* FIXME: make this useful for scripting one day */
+	return (DynamicAny_DynAnyFactory) TC_void;
+}
+
 DynamicAny_DynAny
 DynamicAny_DynAnyFactory_create_dyn_any (
 	DynamicAny_DynAnyFactory obj,
@@ -883,22 +899,22 @@ DynamicAny_DynAny_insert_##apiname (DynamicAny_DynAny       obj,		\
 	return;									\
 }
 
-MAKE_DYNANY_INSERT (short,               short);
-MAKE_DYNANY_INSERT (long,                long);
-MAKE_DYNANY_INSERT (unsigned_short,      ushort);
-MAKE_DYNANY_INSERT (unsigned_long,       ulong);
-MAKE_DYNANY_INSERT (float,               float);
-MAKE_DYNANY_INSERT (double,              double);
-MAKE_DYNANY_INSERT (long_double,         longdouble);
-MAKE_DYNANY_INSERT (boolean,             boolean);
-MAKE_DYNANY_INSERT (char,                char);
-MAKE_DYNANY_INSERT (wchar,               wchar);
-MAKE_DYNANY_INSERT (octet,               octet);
-MAKE_DYNANY_INSERT (TypeCode,            typecode);
-MAKE_DYNANY_INSERT (Object,              reference);
+MAKE_DYNANY_INSERT (short,               short)
+MAKE_DYNANY_INSERT (long,                long)
+MAKE_DYNANY_INSERT (unsigned_short,      ushort)
+MAKE_DYNANY_INSERT (unsigned_long,       ulong)
+MAKE_DYNANY_INSERT (float,               float)
+MAKE_DYNANY_INSERT (double,              double)
+MAKE_DYNANY_INSERT (long_double,         longdouble)
+MAKE_DYNANY_INSERT (boolean,             boolean)
+MAKE_DYNANY_INSERT (char,                char)
+MAKE_DYNANY_INSERT (wchar,               wchar)
+MAKE_DYNANY_INSERT (octet,               octet)
+MAKE_DYNANY_INSERT (TypeCode,            typecode)
+MAKE_DYNANY_INSERT (Object,              reference)
 /* #ifdef HAVE_CORBA_LONG_LONG */
-MAKE_DYNANY_INSERT (long_long,           longlong); 
-MAKE_DYNANY_INSERT (unsigned_long_long,  ulonglong);
+MAKE_DYNANY_INSERT (long_long,           longlong) 
+MAKE_DYNANY_INSERT (unsigned_long_long,  ulonglong)
 /* #endif */
 
 #define MAKE_DYNANY_GET(ctype,tc,apiname)					\
@@ -910,41 +926,41 @@ DynamicAny_DynAny_get_##apiname (DynamicAny_DynAny  obj,			\
 	DynAny       *dynany;							\
 	CORBA_##ctype value;							\
 										\
-	o_return_val_if_fail (obj != NULL, 0);				       	\
+	o_return_val_if_fail (obj != NULL, (CORBA_##ctype)0);				       	\
 										\
 	dynany = GET_DYNANY (obj);						\
 										\
 	/* FIXME: assumes NULL == CORBA_OBJECT_NIL for simplicity */		\
 	b_return_val_if_fail (dynany != NULL &&					\
-			      dynany->any != NULL, 0);				\
+			      dynany->any != NULL, (CORBA_##ctype)0);				\
 										\
 	if (dynany_type_mismatch (dynany, tc, ev))				\
-		return 0;	       						\
+		return (CORBA_##ctype)0;	       						\
 										\
 	dynany_get (dynany, &value, tc, ev);					\
 										\
 	return value;								\
 }
 
-MAKE_DYNANY_GET (short,               TC_CORBA_short,              short);
-MAKE_DYNANY_GET (long,                TC_CORBA_long,               long);
-MAKE_DYNANY_GET (unsigned_short,      TC_CORBA_unsigned_short,     ushort);
-MAKE_DYNANY_GET (unsigned_long,       TC_CORBA_unsigned_long,      ulong);
-MAKE_DYNANY_GET (float,               TC_CORBA_float,              float);
-MAKE_DYNANY_GET (double,              TC_CORBA_double,             double);
-MAKE_DYNANY_GET (long_double,         TC_CORBA_long_double,        longdouble);
-MAKE_DYNANY_GET (boolean,             TC_CORBA_boolean,            boolean);
-MAKE_DYNANY_GET (char,                TC_CORBA_char,               char);
-MAKE_DYNANY_GET (wchar,               TC_CORBA_wchar,              wchar);
-MAKE_DYNANY_GET (octet,               TC_CORBA_octet,              octet);
-MAKE_DYNANY_GET (any *,               TC_CORBA_any,                any);
-MAKE_DYNANY_GET (TypeCode,            TC_CORBA_TypeCode,           typecode);
-MAKE_DYNANY_GET (Object,              TC_CORBA_Object,             reference);
-MAKE_DYNANY_GET (char *,              TC_CORBA_string,             string);
-MAKE_DYNANY_GET (wchar *,             TC_CORBA_wstring,            wstring);
+MAKE_DYNANY_GET (short,               TC_CORBA_short,              short)
+MAKE_DYNANY_GET (long,                TC_CORBA_long,               long)
+MAKE_DYNANY_GET (unsigned_short,      TC_CORBA_unsigned_short,     ushort)
+MAKE_DYNANY_GET (unsigned_long,       TC_CORBA_unsigned_long,      ulong)
+MAKE_DYNANY_GET (float,               TC_CORBA_float,              float)
+MAKE_DYNANY_GET (double,              TC_CORBA_double,             double)
+MAKE_DYNANY_GET (long_double,         TC_CORBA_long_double,        longdouble)
+MAKE_DYNANY_GET (boolean,             TC_CORBA_boolean,            boolean)
+MAKE_DYNANY_GET (char,                TC_CORBA_char,               char)
+MAKE_DYNANY_GET (wchar,               TC_CORBA_wchar,              wchar)
+MAKE_DYNANY_GET (octet,               TC_CORBA_octet,              octet)
+MAKE_DYNANY_GET (any *,               TC_CORBA_any,                any)
+MAKE_DYNANY_GET (TypeCode,            TC_CORBA_TypeCode,           typecode)
+MAKE_DYNANY_GET (Object,              TC_CORBA_Object,             reference)
+MAKE_DYNANY_GET (char *,              TC_CORBA_string,             string)
+MAKE_DYNANY_GET (wchar *,             TC_CORBA_wstring,            wstring)
 /* #ifdef HAVE_CORBA_LONG_LONG */
-MAKE_DYNANY_GET (long_long,           TC_CORBA_long_long,          longlong); 
-MAKE_DYNANY_GET (unsigned_long_long,  TC_CORBA_unsigned_long_long, ulonglong);
+MAKE_DYNANY_GET (long_long,           TC_CORBA_long_long,          longlong) 
+MAKE_DYNANY_GET (unsigned_long_long,  TC_CORBA_unsigned_long_long, ulonglong)
 /* #endif */
 
 /* 9.2.3.9 */
@@ -1398,7 +1414,7 @@ DynamicAny_DynStruct_get_members (DynamicAny_DynStruct obj,
 
 		any->_type = (CORBA_TypeCode) CORBA_Object_duplicate (
 			(CORBA_Object) subtc, ev);
-		to = any->_value = ORBit_alloc_tcval (subtc, 1);
+		to = any->_value = ORBit_alloc_by_tc (subtc);
 		
 		ORBit_copy_value_core (&src, &to, subtc);
 	}
@@ -1655,12 +1671,12 @@ DynamicAny_DynUnion_member_name (DynamicAny_DynUnion obj,
 	DynAny *dynany;
 	CORBA_TypeCode tc;
 	
-	o_return_val_if_fail (obj != NULL, 0);
+	o_return_val_if_fail (obj != NULL, NULL);
 	
 	dynany = GET_DYNANY (obj);
 	b_return_val_if_fail (dynany != NULL &&
 			      dynany->any != NULL &&
-			      dynany->any->_type != NULL, 0);
+			      dynany->any->_type != NULL, NULL);
 
 	tc = dynany->any->_type;
 
@@ -1750,7 +1766,7 @@ DynamicAny_DynSequence_get_elements (DynamicAny_DynSequence obj,
 
 		any->_type = (CORBA_TypeCode) CORBA_Object_duplicate (
 			(CORBA_Object) subtc, ev);
-		to = any->_value = ORBit_alloc_tcval (subtc, 1);
+		to = any->_value = ORBit_alloc_by_tc (subtc);
 		
 		ORBit_copy_value_core (&src, &to, subtc);
 	}
@@ -1808,8 +1824,8 @@ DynamicAny_DynSequence_set_elements (DynamicAny_DynSequence   obj,
 }
 
 DynamicAny_DynAnySeq *
-DynamicAny_DynStruct_get_elements_as_dyn_any (DynamicAny_DynSequence obj,
-					      CORBA_Environment     *ev)
+DynamicAny_DynSequence_get_elements_as_dyn_any (DynamicAny_DynSequence  obj,
+						CORBA_Environment      *ev)
 {
 	DynAny *dynany;
 	int i;
@@ -1845,7 +1861,7 @@ DynamicAny_DynStruct_get_elements_as_dyn_any (DynamicAny_DynSequence obj,
 		subdyn = GET_DYNANY (&s->_buffer [i]);
 		src = subdyn->any->_value;
 
-		(DynamicAny_DynAny) retval->_buffer [i] = dynany_create (subtc, src, dynany, ev);
+		retval->_buffer [i] = (CORBA_Object) dynany_create (subtc, src, dynany, ev);
 	}
 
 	return retval;
